var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};

// src/index.react-server.ts
import "server-only";

// src/query/prefetch.ts
import {
  PostgrestParser as PostgrestParser2,
  isPostgrestBuilder as isPostgrestBuilder2,
  offsetPaginationFetcher,
  offsetPaginationHasMoreFetcher
} from "@supabase-cache-helpers/postgrest-core";

// src/lib/constants.ts
var KEY_PREFIX = "postgrest";
var KEY_SEPARATOR = "$";
var INFINITE_KEY_PREFIX = "page";

// src/lib/create-key-getter.ts
import {
  setFilterValue,
  get,
  isPostgrestHasMorePaginationResponse,
  isPostgrestPaginationResponse
} from "@supabase-cache-helpers/postgrest-core";

// src/lib/encode.ts
var encode = (parser, isInfinite) => {
  var _a;
  return [
    KEY_PREFIX,
    isInfinite ? INFINITE_KEY_PREFIX : "null",
    parser.schema,
    parser.table,
    parser.queryKey,
    (_a = parser.bodyKey) != null ? _a : "null",
    `count=${parser.count}`,
    `head=${parser.isHead}`,
    parser.orderByKey
  ].join(KEY_SEPARATOR);
};

// src/lib/middleware.ts
import {
  PostgrestParser,
  isPostgrestBuilder
} from "@supabase-cache-helpers/postgrest-core";

// src/lib/use-postgrest-filter-cache.ts
import {
  encodeObject,
  PostgrestFilter
} from "@supabase-cache-helpers/postgrest-core";
import { useSWRConfig } from "swr";

// src/lib/use-queries-for-table-loader.ts
import { useSWRConfig as useSWRConfig2 } from "swr";

// src/query/prefetch.ts
function fetchQueryFallbackData(query) {
  return __async(this, null, function* () {
    if (!isPostgrestBuilder2(query)) {
      throw new Error("Query is not a PostgrestBuilder");
    }
    return [
      encode(new PostgrestParser2(query), false),
      yield query.throwOnError()
    ];
  });
}
function fetchOffsetPaginationHasMoreFallbackData(query, pageSize) {
  return __async(this, null, function* () {
    return [
      encode(new PostgrestParser2(query.range(0, pageSize)), true),
      [
        yield offsetPaginationHasMoreFetcher(query, {
          offset: 0,
          limit: pageSize,
          pageSize
        })
      ]
    ];
  });
}
var fetchOffsetPaginationFallbackData = (query, pageSize) => __async(void 0, null, function* () {
  return [
    encode(new PostgrestParser2(query.range(0, pageSize)), true),
    [
      yield offsetPaginationFetcher(query, {
        offset: 0,
        limit: pageSize
      })
    ]
  ];
});
export {
  fetchOffsetPaginationFallbackData,
  fetchOffsetPaginationHasMoreFallbackData,
  fetchQueryFallbackData
};
//# sourceMappingURL=index.react-server.mjs.map